@@ -2,13 +2,13 @@ from ml.ml40.features.properties.values.value import Value
 
 
 class Weight(Value):
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="ml40", name="", identifier="", parent=None):
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
         self.__weight = None
-        self.__json_out = dict()
+        self.__json_out = {}
 
     @property
     def weight(self):
@@ -23,4 +23,3 @@ class Weight(Value):
         if self.weight is not None:
             self.__json_out["weight"] = self.weight
         return self.__json_out
-
