@@ -3,8 +3,7 @@ from ml.mml40.features.properties.values.Stretch import Stretch
 
 
 class ProvidesStretchData(Functionality):
-
-    def __init__(self, name="", identifier=""):
+    def __init__(self, namespace="mml40", name="", identifier="", parent=None):
         """Initializes the object.
 
         :param name: Object name
@@ -12,8 +11,8 @@ class ProvidesStretchData(Functionality):
 
         """
         super().__init__(
-            name=name,
-            identifier=identifier)
+            namespace=namespace, name=name, identifier=identifier, parent=parent
+        )
 
     def getStretchData(self, time) -> Stretch:
         pass
